SIA_EVENTS = {
    "AA": {
        "event": "AA",
        "type": "Alarm - Panel Substitution",
        "description": "An attempt to substitute an alternate alarm panel for a secure panel has been made",
        "concerns": "Condition number",
    },
    "AB": {
        "event": "AB",
        "type": "Abort",
        "description": "An event message was not sent due to User action",
        "concerns": "Zone or point",
    },
    "AF": {
        "event": "AF",
        "type": "Arming Event",
        "description": "Scenario",
        "concerns": "Zone or point",
    },
    "AN": {
        "event": "AN",
        "type": "Analog Restoral",
        "description": "An analog fire sensor has been restored to normal operation",
        "concerns": "Zone or point",
    },
    "AR": {
        "event": "AR",
        "type": "AC Restoral",
        "description": "AC power has been restored",
        "concerns": None,
    },
    "AS": {
        "event": "AS",
        "type": "Analog Service",
        "description": "An analog fire sensor needs to be cleaned or calibrated",
        "concerns": "Zone or point",
    },
    "AT": {
        "event": "AT",
        "type": "AC Trouble",
        "description": "AC power has been failed",
        "concerns": None,
    },
    "BA": {
        "event": "BA",
        "type": "Burglary Alarm",
        "description": "Burglary zone has been violated while armed",
        "concerns": "Zone or point",
    },
    "BB": {
        "event": "BB",
        "type": "Burglary Bypass",
        "description": "Burglary zone has been bypassed",
        "concerns": "Zone or point",
    },
    "BC": {
        "event": "BC",
        "type": "Burglary Cancel",
        "description": "Alarm has been cancelled by authorized user",
        "concerns": "User number",
    },
    "BD": {
        "event": "BD",
        "type": "Swinger Trouble",
        "description": "A non-fire zone has been violated after a Swinger Shutdown on the zone",
        "concerns": "Zone or point",
    },
    "BE": {
        "event": "BE",
        "type": "Swinger Trouble Restore",
        "description": "A non-fire zone restores to normal from a Swinger Trouble state",
        "concerns": "Zone or point",
    },
    "BG": {
        "event": "BG",
        "type": "Unverified Event - Burglary",
        "description": "A point assigned to a Cross Point group has gone into alarm but the Cross Point remained normal",
        "concerns": "Zone or point",
    },
    "BH": {
        "event": "BH",
        "type": "Burglary Alarm Restore",
        "description": "Alarm condition eliminated",
        "concerns": "Zone or point",
    },
    "BJ": {
        "event": "BJ",
        "type": "Burglary Trouble Restore",
        "description": "Trouble condition eliminated",
        "concerns": "Zone or point",
    },
    "BM": {
        "event": "BM",
        "type": "Burglary Alarm - Cross Point",
        "description": "Burglary alarm w/cross point also in alarm - alarm verified",
        "concerns": "Zone or point",
    },
    "BR": {
        "event": "BR",
        "type": "Burglary Restoral",
        "description": "Alarm/trouble condition has been eliminated",
        "concerns": "Zone or point",
    },
    "BS": {
        "event": "BS",
        "type": "Burglary Supervisory",
        "description": "Unsafe intrusion detection system condition",
        "concerns": "Zone or point",
    },
    "BT": {
        "event": "BT",
        "type": "Burglary Trouble",
        "description": "Burglary zone disabled by fault",
        "concerns": "Zone or point",
    },
    "BU": {
        "event": "BU",
        "type": "Burglary Unbypass",
        "description": "Zone bypass has been removed",
        "concerns": "Zone or point",
    },
    "BV": {
        "event": "BV",
        "type": "Burglary Verified",
        "description": "A burglary alarm has occurred and been verified within programmed conditions. (zone or point not sent)",
        "concerns": "Area number",
    },
    "BX": {
        "event": "BX",
        "type": "Burglary Test",
        "description": "Burglary zone activated during testing",
        "concerns": "Zone or point",
    },
    "BZ": {
        "event": "BZ",
        "type": "Missing Supervision",
        "description": "A non-fire Supervisory point has gone missing",
        "concerns": "Zone or point",
    },
    "CA": {
        "event": "CA",
        "type": "Automatic Closing",
        "description": "System armed automatically",
        "concerns": "Area number",
    },
    "CB": {
        "event": "CB",
        "type": "Arming Event",
        "description": "Group has been disarmed automatically",
        "concerns": "Area number",
    },
    "CC": {
        "event": "CC",
        "type": "Arming Event",
        "description": "Unsuccessful arming attempt",
        "concerns": "Area number",
    },
    "CD": {
        "event": "CD",
        "type": "Closing Delinquent",
        "description": "The system has not been armed for a programmed amount of time",
        "concerns": "Area number",
    },
    "CE": {
        "event": "CE",
        "type": "Closing Extend",
        "description": "Extend closing time",
        "concerns": "User number",
    },
    "CF": {
        "event": "CF",
        "type": "Forced Closing",
        "description": "System armed, some zones not ready",
        "concerns": "User number",
    },
    "CG": {
        "event": "CG",
        "type": "Close Area",
        "description": "System has been partially armed",
        "concerns": "Area number",
    },
    "CI": {
        "event": "CI",
        "type": "Fail to Close",
        "description": "An area has not been armed at the end of the closing window",
        "concerns": "Area number",
    },
    "CJ": {
        "event": "CJ",
        "type": "Late Close",
        "description": "An area was armed after the closing window",
        "concerns": "User number",
    },
    "CK": {
        "event": "CK",
        "type": "Early Close",
        "description": "An area was armed before the closing window",
        "concerns": "User number",
    },
    "CL": {
        "event": "CL",
        "type": "Closing Report",
        "description": "System armed, normal",
        "concerns": "User number",
    },
    "CM": {
        "event": "CM",
        "type": "Missing Alarm - Recent Closing",
        "description": "A point has gone missing within 2 minutes of closing",
        "concerns": "Zone or point",
    },
    "CO": {
        "event": "CO",
        "type": "Command Sent",
        "description": "A command has been sent to an expansion/peripheral device",
        "concerns": "Condition number",
    },
    "CP": {
        "event": "CP",
        "type": "Automatic Closing",
        "description": "System armed automatically",
        "concerns": "User number",
    },
    "CQ": {
        "event": "CQ",
        "type": "Remote Closing",
        "description": "The system was armed from a remote location",
        "concerns": "User number",
    },
    "CR": {
        "event": "CR",
        "type": "Recent Closing",
        "description": "An alarm occurred within five minutes after the system was closed",
        "concerns": "User number",
    },
    "CS": {
        "event": "CS",
        "type": "Closing Keyswitch",
        "description": "Account has been armed by keyswitch",
        "concerns": "Zone or point",
    },
    "CT": {
        "event": "CT",
        "type": "Late to Open",
        "description": "System was not disarmed on time",
        "concerns": "Area number",
    },
    "CW": {
        "event": "CW",
        "type": "Was Force Armed",
        "description": "Header for a force armed session, forced point msgs may follow",
        "concerns": "Area number",
    },
    "CX": {
        "event": "CX",
        "type": "Custom Function Executed",
        "description": "The panel has executed a preprogrammed set of instructions",
        "concerns": "Custom Function number",
    },
    "CZ": {
        "event": "CZ",
        "type": "Point Closing",
        "description": "A point, as opposed to a whole area or account, has closed",
        "concerns": "Zone or point",
    },
    "DA": {
        "event": "DA",
        "type": "Card Assigned",
        "description": "An access ID has been added to the controller",
        "concerns": "User number",
    },
    "DB": {
        "event": "DB",
        "type": "Card Deleted",
        "description": "An access ID has been deleted from the controller",
        "concerns": "User number",
    },
    "DC": {
        "event": "DC",
        "type": "Access Closed",
        "description": "Access to all users prohibited",
        "concerns": "Door number",
    },
    "DD": {
        "event": "DD",
        "type": "Access Denied",
        "description": "Access denied, unknown code",
        "concerns": "Door number",
    },
    "DE": {
        "event": "DE",
        "type": "Request to Enter",
        "description": "An access point was opened via a Request to Enter device",
        "concerns": "Door number",
    },
    "DF": {
        "event": "DF",
        "type": "Door Forced",
        "description": "Door opened without access request",
        "concerns": "Door number",
    },
    "DG": {
        "event": "DG",
        "type": "Access Granted",
        "description": "Door access granted",
        "concerns": "Door number",
    },
    "DH": {
        "event": "DH",
        "type": "Door Left Open - Restoral",
        "description": "An access point in a Door Left Open state has restored",
        "concerns": "Door number",
    },
    "DI": {
        "event": "DI",
        "type": "Access Denied - Passback",
        "description": "Access denied because credential has not exited area before attempting to re-enter same area",
        "concerns": "Door number",
    },
    "DJ": {
        "event": "DJ",
        "type": "Door Forced - Trouble",
        "description": "An access point has been forced open in an unarmed area",
        "concerns": "Door number",
    },
    "DK": {
        "event": "DK",
        "type": "Access Lockout",
        "description": "Access denied, known code",
        "concerns": "Door number",
    },
    "DL": {
        "event": "DL",
        "type": "Door Left Open - Alarm",
        "description": "An open access point when open time expired in an armed area",
        "concerns": "Door number",
    },
    "DM": {
        "event": "DM",
        "type": "Door Left Open - Trouble",
        "description": "An open access point when open time expired in an unarmed area",
        "concerns": "Door number",
    },
    "DN": {
        "event": "DN",
        "type": "Door Left Open (non-alarm, non-trouble)",
        "description": "An access point was open when the door cycle time expired",
        "concerns": "Door number",
    },
    "DO": {
        "event": "DO",
        "type": "Access Open",
        "description": "Access to authorized users allowed",
        "concerns": "Door number",
    },
    "DP": {
        "event": "DP",
        "type": "Access Denied - Unauthorized Time",
        "description": "An access request was denied because the request is occurring outside the user’s authorized time window(s)",
        "concerns": "Door number",
    },
    "DQ": {
        "event": "DQ",
        "type": "Access Denied - Unauthorized Arming State",
        "description": "An access request was denied because the user was not authorized in this area when the area was armed",
        "concerns": "Door number",
    },
    "DR": {
        "event": "DR",
        "type": "Door Restoral",
        "description": "Access alarm/trouble condition eliminated",
        "concerns": "Door number",
    },
    "DS": {
        "event": "DS",
        "type": "Door Station",
        "description": "Identifies door for next report",
        "concerns": "Door number",
    },
    "DT": {
        "event": "DT",
        "type": "Access Trouble",
        "description": "Access system trouble",
        "concerns": None,
    },
    "DU": {
        "event": "DU",
        "type": "Dealer ID",
        "description": "Dealer ID number",
        "concerns": "Dealer ID",
    },
    "DV": {
        "event": "DV",
        "type": "Access Denied - Unauthorized Entry Level",
        "description": "An access request was denied because the user is not authorized in this area",
        "concerns": "Door number",
    },
    "DW": {
        "event": "DW",
        "type": "Access Denied - Interlock",
        "description": "An access request was denied because the doors associated Interlock point is open",
        "concerns": "Door number",
    },
    "DX": {
        "event": "DX",
        "type": "Request to Exit",
        "description": "An access point was opened via a Request to Exit device",
        "concerns": "Door number",
    },
    "DY": {
        "event": "DY",
        "type": "Door Locked",
        "description": "The door’s lock has been engaged",
        "concerns": "Door number",
    },
    "DZ": {
        "event": "DZ",
        "type": "Access Denied - Door Secured",
        "description": "An access request was denied because the door has been placed in an Access Closed state",
        "concerns": "Door number",
    },
    "EA": {
        "event": "EA",
        "type": "Exit Alarm",
        "description": "An exit zone remained violated at the end of the exit delay period",
        "concerns": "Zone or point",
    },
    "EE": {
        "event": "EE",
        "type": "Exit Error",
        "description": "An exit zone remained violated at the end of the exit delay period",
        "concerns": "User number",
    },
    "EJ": {
        "event": "EJ",
        "type": "Expansion Tamper Restore",
        "description": "Expansion device tamper restoral",
        "concerns": "Expansion device number",
    },
    "EM": {
        "event": "EM",
        "type": "Expansion Device Missing",
        "description": "Expansion device missing",
        "concerns": "Expansion device number",
    },
    "EN": {
        "event": "EN",
        "type": "Expansion Missing Restore",
        "description": "Expansion device communications re-established",
        "concerns": "Expansion device number",
    },
    "ER": {
        "event": "ER",
        "type": "Expansion Restoral",
        "description": "Expansion device trouble eliminated",
        "concerns": "Expander number",
    },
    "ES": {
        "event": "ES",
        "type": "Expansion Device Tamper",
        "description": "Expansion device enclosure tamper",
        "concerns": "Expansion device number",
    },
    "ET": {
        "event": "ET",
        "type": "Expansion Trouble",
        "description": "Expansion device trouble",
        "concerns": "Expander number",
    },
    "EX": {
        "event": "EX",
        "type": "External Device Condition",
        "description": "A specific reportable condition is detected on an external device",
        "concerns": "Device number",
    },
    "EZ": {
        "event": "EZ",
        "type": "Missing Alarm - Exit Error",
        "description": "A point remained missing at the end of the exit delay period",
        "concerns": "Point number",
    },
    "FA": {
        "event": "FA",
        "type": "Fire Alarm",
        "description": "Fire condition detected",
        "concerns": "Zone or point",
    },
    "FB": {
        "event": "FB",
        "type": "Fire Bypass",
        "description": "Zone has been bypassed",
        "concerns": "Zone or point",
    },
    "FC": {
        "event": "FC",
        "type": "Fire Cancel",
        "description": "A Fire Alarm has been cancelled by an authorized person",
        "concerns": "Zone or point",
    },
    "FG": {
        "event": "FG",
        "type": "Unverified Event - Fire",
        "description": "A point assigned to a Cross Point group has gone into alarm but the Cross Point remained normal",
        "concerns": "Zone or point",
    },
    "FH": {
        "event": "FH",
        "type": "Fire Alarm Restore",
        "description": "Alarm condition eliminated",
        "concerns": "Zone or point",
    },
    "FI": {
        "event": "FI",
        "type": "Fire Test Begin",
        "description": "The transmitter area's fire test has begun",
        "concerns": "Area number",
    },
    "FJ": {
        "event": "FJ",
        "type": "Fire Trouble Restore",
        "description": "Trouble condition eliminated",
        "concerns": "Zone or point",
    },
    "FK": {
        "event": "FK",
        "type": "Fire Test End",
        "description": "The transmitter area's fire test has ended",
        "concerns": "Area number",
    },
    "FL": {
        "event": "FL",
        "type": "Fire Alarm Silenced",
        "description": "The fire panel’s sounder was silenced by command",
        "concerns": "Zone or point",
    },
    "FM": {
        "event": "FM",
        "type": "Fire Alarm - Cross Point",
        "description": "Fire Alarm with Cross Point also in alarm verifying the Fire Alarm",
        "concerns": "Point number",
    },
    "FQ": {
        "event": "FQ",
        "type": "Fire Supervisory Trouble Restore",
        "description": "A fire supervisory zone that was in trouble condition has now restored to normal",
        "concerns": "Zone or point",
    },
    "FR": {
        "event": "FR",
        "type": "Fire Restoral",
        "description": "Alarm/trouble condition has been eliminated",
        "concerns": "Zone or point",
    },
    "FS": {
        "event": "FS",
        "type": "Fire Supervisory",
        "description": "Unsafe fire detection system condition",
        "concerns": "Zone or point",
    },
    "FT": {
        "event": "FT",
        "type": "Fire Trouble",
        "description": "Zone disabled by fault",
        "concerns": "Zone or point",
    },
    "FU": {
        "event": "FU",
        "type": "Fire Unbypass",
        "description": "Bypass has been removed",
        "concerns": "Zone or point",
    },
    "FV": {
        "event": "FV",
        "type": "Fire Supervision Restore",
        "description": "A fire supervision zone that was in alarm has restored to normal",
        "concerns": "Zone or point",
    },
    "FW": {
        "event": "FW",
        "type": "Fire Supervisory Trouble",
        "description": "A fire supervisory zone is now in a trouble condition",
        "concerns": "Zone or point",
    },
    "FX": {
        "event": "FX",
        "type": "Fire Test",
        "description": "Fire zone activated during test",
        "concerns": "Zone or point",
    },
    "FY": {
        "event": "FY",
        "type": "Missing Fire Trouble",
        "description": "A fire point is now logically missing",
        "concerns": "Zone or point",
    },
    "FZ": {
        "event": "FZ",
        "type": "Missing Fire Supervision",
        "description": "A Fire Supervisory point has gone missing",
        "concerns": "Zone or point",
    },
    "GA": {
        "event": "GA",
        "type": "Gas Alarm",
        "description": "Gas alarm condition detected",
        "concerns": "Zone or point",
    },
    "GB": {
        "event": "GB",
        "type": "Gas Bypass",
        "description": "Zone has been bypassed",
        "concerns": "Zone or point",
    },
    "GH": {
        "event": "GH",
        "type": "Gas Alarm Restore",
        "description": "Alarm condition eliminated",
        "concerns": "Zone or point",
    },
    "GJ": {
        "event": "GJ",
        "type": "Gas Trouble Restore",
        "description": "Trouble condition eliminated",
        "concerns": "Zone or point",
    },
    "GR": {
        "event": "GR",
        "type": "Gas Restoral",
        "description": "Alarm/trouble condition has been eliminated",
        "concerns": "Zone or point",
    },
    "GS": {
        "event": "GS",
        "type": "Gas Supervisory",
        "description": "Unsafe gas detection system condition",
        "concerns": "Zone or point",
    },
    "GT": {
        "event": "GT",
        "type": "Gas Trouble",
        "description": "Zone disabled by fault",
        "concerns": "Zone or point",
    },
    "GU": {
        "event": "GU",
        "type": "Gas Unbypass",
        "description": "Bypass has been removed",
        "concerns": "Zone or point",
    },
    "GX": {
        "event": "GX",
        "type": "Gas Test",
        "description": "Zone activated during test",
        "concerns": "Zone or point",
    },
    "HA": {
        "event": "HA",
        "type": "Holdup Alarm",
        "description": "Silent alarm, user under duress",
        "concerns": "Zone or point",
    },
    "HB": {
        "event": "HB",
        "type": "Holdup Bypass",
        "description": "Zone has been bypassed",
        "concerns": "Zone or point",
    },
    "HH": {
        "event": "HH",
        "type": "Holdup Alarm Restore",
        "description": "Alarm condition eliminated",
        "concerns": "Zone or point",
    },
    "HJ": {
        "event": "HJ",
        "type": "Holdup Trouble Restore",
        "description": "Trouble condition eliminated",
        "concerns": "Zone or point",
    },
    "HR": {
        "event": "HR",
        "type": "Holdup Restoral",
        "description": "Alarm/trouble condition has been eliminated",
        "concerns": "Zone or point",
    },
    "HS": {
        "event": "HS",
        "type": "Holdup Supervisory",
        "description": "Unsafe holdup system condition",
        "concerns": "Zone or point",
    },
    "HT": {
        "event": "HT",
        "type": "Holdup Trouble",
        "description": "Zone disabled by fault",
        "concerns": "Zone or point",
    },
    "HU": {
        "event": "HU",
        "type": "Holdup Unbypass",
        "description": "Bypass has been removed",
        "concerns": "Zone or point",
    },
    "IA": {
        "event": "IA",
        "type": "Equipment Failure Condition",
        "description": "A specific, reportable condition is detected on a device",
        "concerns": "Point number",
    },
    "IR": {
        "event": "IR",
        "type": "Equipment Fail - Restoral",
        "description": "The equipment condition has been restored to normal",
        "concerns": "Point number",
    },
    "JA": {
        "event": "JA",
        "type": "User code Tamper",
        "description": "Too many unsuccessful attempts have been made to enter a user ID",
        "concerns": "Area number",
    },
    "JC": {
        "event": "JC",
        "type": "User code tamper canceled",
        "description": "Break password restore",
        "concerns": "Area number",
    },
    "JD": {
        "event": "JD",
        "type": "Date Changed",
        "description": "The date was changed in the transmitter/receiver",
        "concerns": "User number",
    },
    "JH": {
        "event": "JH",
        "type": "Holiday Changed",
        "description": "The transmitter's holiday schedule has been changed",
        "concerns": "User number",
    },
    "JK": {
        "event": "JK",
        "type": "Latchkey Alert",
        "description": "A designated user passcode has not been entered during a scheduled time window",
        "concerns": "User number",
    },
    "JL": {
        "event": "JL",
        "type": "Log Threshold",
        "description": "The transmitter's log memory has reached its threshold level",
        "concerns": None,
    },
    "JO": {
        "event": "JO",
        "type": "Log Overflow",
        "description": "The transmitter's log memory has overflowed",
        "concerns": None,
    },
    "JP": {
        "event": "JP",
        "type": "User On Premises",
        "description": "A designated user passcode has been used to gain access to the premises.",
        "concerns": "User number",
    },
    "JR": {
        "event": "JR",
        "type": "Schedule Executed",
        "description": "An automatic scheduled event was executed",
        "concerns": "Area number",
    },
    "JS": {
        "event": "JS",
        "type": "Schedule Changed",
        "description": "An automatic schedule was changed",
        "concerns": "User number",
    },
    "JT": {
        "event": "JT",
        "type": "Time Changed",
        "description": "The time was changed in the transmitter/receiver",
        "concerns": "User number",
    },
    "JV": {
        "event": "JV",
        "type": "User code Changed",
        "description": "A user's code has been changed",
        "concerns": "User number",
    },
    "JX": {
        "event": "JX",
        "type": "User code Deleted",
        "description": "A user's code has been removed",
        "concerns": "User number",
    },
    "JY": {
        "event": "JY",
        "type": "User code Added",
        "description": "A user’s code has been added",
        "concerns": "User number",
    },
    "JZ": {
        "event": "JZ",
        "type": "User Level Set",
        "description": "A user’s authority level has been set",
        "concerns": "User number",
    },
    "KA": {
        "event": "KA",
        "type": "Heat Alarm",
        "description": "High temperature detected on premise",
        "concerns": "Zone or point",
    },
    "KB": {
        "event": "KB",
        "type": "Heat Bypass",
        "description": "Zone has been bypassed",
        "concerns": "Zone or point",
    },
    "KH": {
        "event": "KH",
        "type": "Heat Alarm Restore",
        "description": "Alarm condition eliminated",
        "concerns": "Zone or point",
    },
    "KJ": {
        "event": "KJ",
        "type": "Heat Trouble Restore",
        "description": "Trouble condition eliminated",
        "concerns": "Zone or point",
    },
    "KR": {
        "event": "KR",
        "type": "Heat Restoral",
        "description": "Alarm/trouble condition has been eliminated",
        "concerns": "Zone or point",
    },
    "KS": {
        "event": "KS",
        "type": "Heat Supervisory",
        "description": "Unsafe heat detection system condition",
        "concerns": "Zone or point",
    },
    "KT": {
        "event": "KT",
        "type": "Heat Trouble",
        "description": "Zone disabled by fault",
        "concerns": "Zone or point",
    },
    "KU": {
        "event": "KU",
        "type": "Heat Unbypass",
        "description": "Bypass has been removed",
        "concerns": "Zone or point",
    },
    "LB": {
        "event": "LB",
        "type": "Local Program",
        "description": "Begin local programming",
        "concerns": None,
    },
    "LD": {
        "event": "LD",
        "type": "Local Program Denied",
        "description": "Access code incorrect",
        "concerns": None,
    },
    "LE": {
        "event": "LE",
        "type": "Listen-in Ended",
        "description": "The listen-in session has been terminated",
        "concerns": None,
    },
    "LF": {
        "event": "LF",
        "type": "Listen-in Begin",
        "description": "The listen-in session with the RECEIVER has begun",
        "concerns": None,
    },
    "LR": {
        "event": "LR",
        "type": "Phone Line Restoral",
        "description": "Phone line restored to service",
        "concerns": "Line number",
    },
    "LS": {
        "event": "LS",
        "type": "Local Program Success",
        "description": "Local programming successful",
        "concerns": None,
    },
    "LT": {
        "event": "LT",
        "type": "Phone Line Trouble",
        "description": "Phone line trouble report",
        "concerns": "Line number",
    },
    "LU": {
        "event": "LU",
        "type": "Local Program Fail",
        "description": "Local programming unsuccessful",
        "concerns": None,
    },
    "LX": {
        "event": "LX",
        "type": "Local Programming Ended",
        "description": "A local programming session has been terminated",
        "concerns": None,
    },
    "MA": {
        "event": "MA",
        "type": "Medical Alarm",
        "description": "Emergency assistance request",
        "concerns": "Zone or point",
    },
    "MB": {
        "event": "MB",
        "type": "Medical Bypass",
        "description": "Zone has been bypassed",
        "concerns": "Zone or point",
    },
    "MH": {
        "event": "MH",
        "type": "Medical Alarm Restore",
        "description": "Alarm condition eliminated",
        "concerns": "Zone or point",
    },
    "MI": {
        "event": "MI",
        "type": "Message",
        "description": "A canned message is being sent",
        "concerns": "Message number",
    },
    "MJ": {
        "event": "MJ",
        "type": "Medical Trouble Restore",
        "description": "Trouble condition eliminated",
        "concerns": "Zone or point",
    },
    "MR": {
        "event": "MR",
        "type": "Medical Restoral",
        "description": "Alarm/trouble condition has been eliminated",
        "concerns": "Zone or point",
    },
    "MS": {
        "event": "MS",
        "type": "Medical Supervisory",
        "description": "Unsafe system condition exists",
        "concerns": "Zone or point",
    },
    "MT": {
        "event": "MT",
        "type": "Medical Trouble",
        "description": "Zone disabled by fault",
        "concerns": "Zone or point",
    },
    "MU": {
        "event": "MU",
        "type": "Medical Unbypass",
        "description": "Bypass has been removed",
        "concerns": "Zone or point",
    },
    "NA": {
        "event": "NA",
        "type": "No Activity",
        "description": "There has been no zone activity for a programmed amount of time",
        "concerns": "Zone number",
    },
    "NB": {
        "event": "NB",
        "type": "Arming Event",
        "description": "Scenario",
        "concerns": "Area number",
    },
    "NC": {
        "event": "NC",
        "type": "Network Condition",
        "description": "A communications network has a specific reportable condition",
        "concerns": "Network number",
    },
    "ND": {
        "event": "ND",
        "type": "Arming Event",
        "description": "Night mode deactivated - duress",
        "concerns": "Area number",
    },
    "NE": {
        "event": "NE",
        "type": "Arming Event",
        "description": "Unsuccessful Night mode activation attempt",
        "concerns": "Area number",
    },
    "NF": {
        "event": "NF",
        "type": "Forced Perimeter Arm",
        "description": "Some zones/points not ready",
        "concerns": "Area number",
    },
    "NL": {
        "event": "NL",
        "type": "Perimeter Armed",
        "description": "An area has been perimeter armed",
        "concerns": "Area number",
    },
    "NM": {
        "event": "NM",
        "type": "Perimeter Armed, User Defined",
        "description": "A user defined area has been perimeter armed",
        "concerns": "Area number",
    },
    "NO": {
        "event": "NO",
        "type": "Arming Event",
        "description": "Night mode deactivated automatically",
        "concerns": "Area number",
    },
    "NP": {
        "event": "NP",
        "type": "Arming Event",
        "description": "Night mode deactivated using device",
        "concerns": "Zone or point",
    },
    "NR": {
        "event": "NR",
        "type": "Network Restoral",
        "description": "A communications network has returned to normal operation",
        "concerns": "Network number",
    },
    "NS": {
        "event": "NS",
        "type": "Activity Resumed",
        "description": "A zone has detected activity after an alert",
        "concerns": "Zone number",
    },
    "NT": {
        "event": "NT",
        "type": "Network Failure",
        "description": "A communications network has failed",
        "concerns": "Network number",
    },
    "OA": {
        "event": "OA",
        "type": "Automatic Opening",
        "description": "System has disarmed automatically",
        "concerns": "Area number",
    },
    "OB": {
        "event": "OB",
        "type": "Arming Event",
        "description": "Group has been disarmed automatically",
        "concerns": "Area number",
    },
    "OC": {
        "event": "OC",
        "type": "Cancel Report",
        "description": "Untyped zone cancel",
        "concerns": "User number",
    },
    "OG": {
        "event": "OG",
        "type": "Open Area",
        "description": "System has been partially disarmed",
        "concerns": "Area number",
    },
    "OH": {
        "event": "OH",
        "type": "Early to Open from Alarm",
        "description": "An area in alarm was disarmed before the opening window",
        "concerns": "User number",
    },
    "OI": {
        "event": "OI",
        "type": "Fail to Open",
        "description": "An area has not been armed at the end of the opening window",
        "concerns": "Area number",
    },
    "OJ": {
        "event": "OJ",
        "type": "Late Open",
        "description": "An area was disarmed after the opening window",
        "concerns": "User number",
    },
    "OK": {
        "event": "OK",
        "type": "Early Open",
        "description": "An area was disarmed before the opening window",
        "concerns": "User number",
    },
    "OL": {
        "event": "OL",
        "type": "Late to Open from Alarm",
        "description": "An area in alarm was disarmed after the opening window",
        "concerns": "User number",
    },
    "OP": {
        "event": "OP",
        "type": "Opening Report",
        "description": "Account was disarmed",
        "concerns": "User number",
    },
    "OQ": {
        "event": "OQ",
        "type": "Remote Opening",
        "description": "The system was disarmed from a remote location",
        "concerns": "User number",
    },
    "OR": {
        "event": "OR",
        "type": "Disarm From Alarm",
        "description": "Account in alarm was reset/disarmed",
        "concerns": "User number",
    },
    "OS": {
        "event": "OS",
        "type": "Opening Keyswitch",
        "description": "Account has been disarmed by keyswitch",
        "concerns": "Zone or point",
    },
    "OT": {
        "event": "OT",
        "type": "Late To Close",
        "description": "System was not armed on time",
        "concerns": "User number",
    },
    "OU": {
        "event": "OU",
        "type": "Output State - Trouble",
        "description": "An output on a peripheral device or NAC is not functioning",
        "concerns": "Output number",
    },
    "OV": {
        "event": "OV",
        "type": "Output State - Restore",
        "description": "An output on a peripheral device or NAC is back to normal operation",
        "concerns": "Output number",
    },
    "OZ": {
        "event": "OZ",
        "type": "Point Opening",
        "description": "A point, rather than a full area or account, disarmed",
        "concerns": "Zone or point",
    },
    "PA": {
        "event": "PA",
        "type": "Panic Alarm",
        "description": "Emergency assistance request, manually activated",
        "concerns": "Zone or point",
    },
    "PB": {
        "event": "PB",
        "type": "Panic Bypass",
        "description": "Panic zone has been bypassed",
        "concerns": "Zone or point",
    },
    "PC": {
        "event": "PC",
        "type": "Photo on demand enabled",
        "description": "Photo on demand enabled",
        "concerns": "User",
    },
    "PD": {
        "event": "PD",
        "type": "Photo on demand disabled",
        "description": "Photo on demand disabled",
        "concerns": "User",
    },
    "PE": {
        "event": "PE",
        "type": "Photo by scenario enable",
        "description": "Photo by alarm scenarios feature enabled for this hub",
        "concerns": None,
    },
    "PF": {
        "event": "PF",
        "type": "Malfunction",
        "description": "MotionCam lost connection with hub over photos communication channel",
        "concerns": "Zone or point",
    },
    "PG": {
        "event": "PG",
        "type": "Photo by scenario disable",
        "description": "Photo by alarm scenarios feature disabled for this hub",
        "concerns": None,
    },
    "PH": {
        "event": "PH",
        "type": "Panic Alarm Restore",
        "description": "Alarm condition eliminated",
        "concerns": "Zone or point",
    },
    "PJ": {
        "event": "PJ",
        "type": "Panic Trouble Restore",
        "description": "Trouble condition eliminated",
        "concerns": "Zone or point",
    },
    "PO": {
        "event": "PO",
        "type": "Malfunction restore",
        "description": "Connection restored, device in room",
        "concerns": None,
    },
    "PR": {
        "event": "PR",
        "type": "Panic Restoral",
        "description": "Alarm/trouble condition has been eliminated",
        "concerns": "Zone or point",
    },
    "PS": {
        "event": "PS",
        "type": "Panic Supervisory",
        "description": "Unsafe system condition exists",
        "concerns": "Zone or point",
    },
    "PT": {
        "event": "PT",
        "type": "Panic Trouble",
        "description": "Zone disabled by fault",
        "concerns": "Zone or point",
    },
    "PU": {
        "event": "PU",
        "type": "Panic Unbypass",
        "description": "Panic zone bypass has been removed",
        "concerns": "Zone or point",
    },
    "QA": {
        "event": "QA",
        "type": "Emergency Alarm",
        "description": "Emergency assistance request",
        "concerns": "Zone or point",
    },
    "QB": {
        "event": "QB",
        "type": "Emergency Bypass",
        "description": "Zone has been bypassed",
        "concerns": "Zone or point",
    },
    "QH": {
        "event": "QH",
        "type": "Emergency Alarm Restore",
        "description": "Alarm condition has been eliminated",
        "concerns": "Zone or point",
    },
    "QJ": {
        "event": "QJ",
        "type": "Emergency Trouble Restore",
        "description": "Trouble condition has been eliminated",
        "concerns": "Zone or point",
    },
    "QR": {
        "event": "QR",
        "type": "Emergency Restoral",
        "description": "Alarm/trouble condition has been eliminated",
        "concerns": "Zone or point",
    },
    "QS": {
        "event": "QS",
        "type": "Emergency Supervisory",
        "description": "Unsafe system condition exists",
        "concerns": "Zone or point",
    },
    "QT": {
        "event": "QT",
        "type": "Emergency Trouble",
        "description": "Zone disabled by fault",
        "concerns": "Zone or point",
    },
    "QU": {
        "event": "QU",
        "type": "Emergency Unbypass",
        "description": "Bypass has been removed",
        "concerns": "Zone or point",
    },
    "RA": {
        "event": "RA",
        "type": "Remote Programmer Call Failed",
        "description": "Transmitter failed to communicate with the remote programmer",
        "concerns": None,
    },
    "RB": {
        "event": "RB",
        "type": "Remote Program Begin",
        "description": "Remote programming session initiated",
        "concerns": None,
    },
    "RC": {
        "event": "RC",
        "type": "Relay Close",
        "description": "A relay has energized",
        "concerns": "Relay number",
    },
    "RD": {
        "event": "RD",
        "type": "Remote Program Denied",
        "description": "Access passcode incorrect",
        "concerns": None,
    },
    "RN": {
        "event": "RN",
        "type": "Remote Reset",
        "description": "A TRANSMITTER was reset via a remote programmer",
        "concerns": None,
    },
    "RO": {
        "event": "RO",
        "type": "Relay Open",
        "description": "A relay has de-energized",
        "concerns": "Relay number",
    },
    "RP": {
        "event": "RP",
        "type": "Automatic Test",
        "description": "Automatic communication test report",
        "concerns": None,
    },
    "RR": {
        "event": "RR",
        "type": "Power Up",
        "description": "System lost power, is now restored",
        "concerns": None,
    },
    "RS": {
        "event": "RS",
        "type": "Remote Program Success",
        "description": "Remote programming successful",
        "concerns": None,
    },
    "RT": {
        "event": "RT",
        "type": "Data Lost",
        "description": "Dialer data lost, transmission error",
        "concerns": "Line number",
    },
    "RU": {
        "event": "RU",
        "type": "Remote Program Fail",
        "description": "Remote programming unsuccessful",
        "concerns": None,
    },
    "RX": {
        "event": "RX",
        "type": "Manual Test",
        "description": "Manual communication test report",
        "concerns": "User number",
    },
    "RY": {
        "event": "RY",
        "type": "Test Off Normal",
        "description": "Test signal(s) indicates abnormal condition(s) exist",
        "concerns": "Zone or point",
    },
    "SA": {
        "event": "SA",
        "type": "Sprinkler Alarm",
        "description": "Sprinkler flow condition exists",
        "concerns": "Zone or point",
    },
    "SB": {
        "event": "SB",
        "type": "Sprinkler Bypass",
        "description": "Sprinkler zone has been bypassed",
        "concerns": "Zone or point",
    },
    "SC": {
        "event": "SC",
        "type": "Change of State",
        "description": "An expansion/peripheral device is reporting a new condition or state change",
        "concerns": "Condition number",
    },
    "SH": {
        "event": "SH",
        "type": "Sprinkler Alarm Restore",
        "description": "Alarm condition eliminated",
        "concerns": "Zone or point",
    },
    "SJ": {
        "event": "SJ",
        "type": "Sprinkler Trouble Restore",
        "description": "Trouble condition eliminated",
        "concerns": "Zone or point",
    },
    "SM": {
        "event": "SM",
        "type": "Malfunction",
        "description": "LeakProtect Malfunction",
        "concerns": "Zone or point",
    },
    "SR": {
        "event": "SR",
        "type": "Sprinkler Restoral",
        "description": "Alarm/trouble condition has been eliminated",
        "concerns": "Zone or point",
    },
    "SS": {
        "event": "SS",
        "type": "Sprinkler Supervisory",
        "description": "Unsafe sprinkler system condition",
        "concerns": "Zone or point",
    },
    "ST": {
        "event": "ST",
        "type": "Sprinkler Trouble",
        "description": "Zone disabled by fault",
        "concerns": "Zone or point",
    },
    "SU": {
        "event": "SU",
        "type": "Sprinkler Unbypass",
        "description": "Sprinkler zone bypass has been removed",
        "concerns": "Zone or point",
    },
    "TA": {
        "event": "TA",
        "type": "Tamper Alarm",
        "description": "Alarm equipment enclosure opened",
        "concerns": "Zone or point",
    },
    "TB": {
        "event": "TB",
        "type": "Tamper Bypass",
        "description": "Tamper detection has been bypassed",
        "concerns": "Zone or point",
    },
    "TC": {
        "event": "TC",
        "type": "All Points Tested",
        "description": "All point tested",
        "concerns": None,
    },
    "TE": {
        "event": "TE",
        "type": "Test End",
        "description": "Communicator restored to operation",
        "concerns": None,
    },
    "TH": {
        "event": "TH",
        "type": "Tamper Alarm Restore",
        "description": "An Expansion Device’s tamper switch restores to normal from an Alarm state",
        "concerns": None,
    },
    "TJ": {
        "event": "TJ",
        "type": "Tamper Trouble Restore",
        "description": "An Expansion Device’s tamper switch restores to normal from a Trouble state",
        "concerns": None,
    },
    "TP": {
        "event": "TP",
        "type": "Walk Test Point",
        "description": "This point was tested during a Walk Test",
        "concerns": "Point number",
    },
    "TR": {
        "event": "TR",
        "type": "Tamper Restoral",
        "description": "Alarm equipment enclosure has been closed",
        "concerns": "Zone or point",
    },
    "TS": {
        "event": "TS",
        "type": "Test Start",
        "description": "Communicator taken out of operation",
        "concerns": None,
    },
    "TT": {
        "event": "TT",
        "type": "Tamper Trouble",
        "description": "Equipment enclosure opened in disarmed state",
        "concerns": "Zone or point",
    },
    "TU": {
        "event": "TU",
        "type": "Tamper Unbypass",
        "description": "Tamper detection bypass has been removed",
        "concerns": "Zone or point",
    },
    "TW": {
        "event": "TW",
        "type": "Area Watch Start",
        "description": "Area watch feature has been activated",
        "concerns": None,
    },
    "TX": {
        "event": "TX",
        "type": "Test Report",
        "description": "An unspecified (manual or automatic) communicator test",
        "concerns": None,
    },
    "TZ": {
        "event": "TZ",
        "type": "Area Watch End",
        "description": "Area watch feature has been deactivated",
        "concerns": None,
    },
    "UA": {
        "event": "UA",
        "type": "Untyped Zone Alarm",
        "description": "Alarm condition from zone of unknown type",
        "concerns": "Zone or point",
    },
    "UB": {
        "event": "UB",
        "type": "Untyped Zone Bypass",
        "description": "Zone of unknown type has been bypassed",
        "concerns": "Zone or point",
    },
    "UG": {
        "event": "UG",
        "type": "Unverified Event - Untyped",
        "description": "A point assigned to a Cross Point group has gone into alarm but the Cross Point remained normal",
        "concerns": "Zone or point",
    },
    "UH": {
        "event": "UH",
        "type": "Untyped Alarm Restore",
        "description": "Alarm condition eliminated",
        "concerns": "Zone or point",
    },
    "UJ": {
        "event": "UJ",
        "type": "Untyped Trouble Restore",
        "description": "Trouble condition eliminated",
        "concerns": "Zone or point",
    },
    "UR": {
        "event": "UR",
        "type": "Untyped Zone Restoral",
        "description": "Alarm/trouble condition eliminated from zone of unknown type",
        "concerns": "Zone or point",
    },
    "US": {
        "event": "US",
        "type": "Untyped Zone Supervisory",
        "description": "Unsafe condition from zone of unknown type",
        "concerns": "Zone or point",
    },
    "UT": {
        "event": "UT",
        "type": "Untyped Zone Trouble",
        "description": "Trouble condition from zone of unknown type",
        "concerns": "Zone or point",
    },
    "UU": {
        "event": "UU",
        "type": "Untyped Zone Unbypass",
        "description": "Bypass on zone of unknown type has been removed",
        "concerns": "Zone or point",
    },
    "UX": {
        "event": "UX",
        "type": "Undefined",
        "description": "An undefined alarm condition has occurred",
        "concerns": None,
    },
    "UY": {
        "event": "UY",
        "type": "Untyped Missing Trouble",
        "description": "A point or device which was not armed is now logically missing",
        "concerns": "Zone or point",
    },
    "UZ": {
        "event": "UZ",
        "type": "Untyped Missing Alarm",
        "description": "A point or device which was armed is now logically missing",
        "concerns": "Zone or point",
    },
    "VI": {
        "event": "VI",
        "type": "Printer Paper In",
        "description": "TRANSMITTER or RECEIVER paper in",
        "concerns": "Printer number",
    },
    "VO": {
        "event": "VO",
        "type": "Printer Paper Out",
        "description": "TRANSMITTER or RECEIVER paper out",
        "concerns": "Printer number",
    },
    "VR": {
        "event": "VR",
        "type": "Printer Restore",
        "description": "TRANSMITTER or RECEIVER trouble restored",
        "concerns": "Printer number",
    },
    "VT": {
        "event": "VT",
        "type": "Printer Trouble",
        "description": "TRANSMITTER or RECEIVER trouble",
        "concerns": "Printer number",
    },
    "VX": {
        "event": "VX",
        "type": "Printer Test",
        "description": "TRANSMITTER or RECEIVER test",
        "concerns": "Printer number",
    },
    "VY": {
        "event": "VY",
        "type": "Printer Online",
        "description": "RECEIVER’S printer is now online",
        "concerns": None,
    },
    "VZ": {
        "event": "VZ",
        "type": "Printer Offline",
        "description": "RECEIVER’S printer is now offline",
        "concerns": None,
    },
    "WA": {
        "event": "WA",
        "type": "Water Alarm",
        "description": "Water detected at protected premises",
        "concerns": "Zone or point",
    },
    "WB": {
        "event": "WB",
        "type": "Water Bypass",
        "description": "Water detection has been bypassed",
        "concerns": "Zone or point",
    },
    "WH": {
        "event": "WH",
        "type": "Water Alarm Restore",
        "description": "Water alarm condition eliminated",
        "concerns": "Zone or point",
    },
    "WJ": {
        "event": "WJ",
        "type": "Water Trouble Restore",
        "description": "Water trouble condition eliminated",
        "concerns": "Zone or point",
    },
    "WR": {
        "event": "WR",
        "type": "Water Restoral",
        "description": "Water alarm/trouble condition has been eliminated",
        "concerns": "Zone or point",
    },
    "WS": {
        "event": "WS",
        "type": "Water Supervisory",
        "description": "Water unsafe water detection system condition",
        "concerns": "Zone or point",
    },
    "WT": {
        "event": "WT",
        "type": "Water Trouble",
        "description": "Water zone disabled by fault",
        "concerns": "Zone or point",
    },
    "WU": {
        "event": "WU",
        "type": "Water Unbypass",
        "description": "Water detection bypass has been removed",
        "concerns": "Zone or point",
    },
    "XA": {
        "event": "XA",
        "type": "Extra Account Report",
        "description": "CS RECEIVER has received an event from a non-existent account",
        "concerns": None,
    },
    "XC": {
        "event": "XC",
        "type": "Malfunction restore",
        "description": "Connection restored, device in room",
        "concerns": None,
    },
    "XE": {
        "event": "XE",
        "type": "Extra Point",
        "description": "Panel has sensed an extra point not specified for this site",
        "concerns": "Point number",
    },
    "XF": {
        "event": "XF",
        "type": "Extra RF Point",
        "description": "Panel has sensed an extra RF point not specified for this site",
        "concerns": "Point number",
    },
    "XH": {
        "event": "XH",
        "type": "RF Interference Restoral",
        "description": "A radio device is no longer detecting RF Interference",
        "concerns": "Receiver number",
    },
    "XI": {
        "event": "XI",
        "type": "Sensor Reset",
        "description": "A user has reset a sensor",
        "concerns": "Zone or point",
    },
    "XJ": {
        "event": "XJ",
        "type": "RF Receiver Tamper Restoral",
        "description": "A Tamper condition at a premises RF Receiver has been restored",
        "concerns": "Receiver number",
    },
    "XL": {
        "event": "XL",
        "type": "Low Received Signal Strength/Connection Lost",
        "description": "The RF signal strength of a reported event is below minimum level",
        "concerns": "Receiver number",
    },
    "XM": {
        "event": "XM",
        "type": "Missing Alarm - Cross Point",
        "description": "Missing Alarm verified by Cross Point in Alarm (or missing)",
        "concerns": "Zone or point",
    },
    "XQ": {
        "event": "XQ",
        "type": "RF Interference",
        "description": "A radio device is detecting RF Interference",
        "concerns": "Receiver number",
    },
    "XR": {
        "event": "XR",
        "type": "Transmitter Battery Restoral",
        "description": "Low battery has been corrected",
        "concerns": "Zone or point",
    },
    "XS": {
        "event": "XS",
        "type": "RF Receiver Tamper",
        "description": "A Tamper condition at a premises receiver is detected",
        "concerns": "Receiver number",
    },
    "XT": {
        "event": "XT",
        "type": "Transmitter Battery Trouble",
        "description": "Low battery in wireless transmitter",
        "concerns": "Zone or point",
    },
    "XW": {
        "event": "XW",
        "type": "Forced Point",
        "description": "A point was forced out of the system at arm time",
        "concerns": "Zone or point",
    },
    "XX": {
        "event": "XX",
        "type": "Fail to Test",
        "description": "A specific test from a panel was not received",
        "concerns": None,
    },
    "YA": {
        "event": "YA",
        "type": "Bell Fault",
        "description": "A trouble condition has been detected on a Local Bell, Siren, or Annunciator",
        "concerns": None,
    },
    "YB": {
        "event": "YB",
        "type": "Busy Seconds",
        "description": "Percent of time receiver's line card is on-line",
        "concerns": "Line card number",
    },
    "YC": {
        "event": "YC",
        "type": "Communications Fail",
        "description": "RECEIVER and TRANSMITTER",
        "concerns": None,
    },
    "YD": {
        "event": "YD",
        "type": "Receiver Line Card Trouble",
        "description": "A line card identified by the passed address is in trouble",
        "concerns": "Line card number",
    },
    "YE": {
        "event": "YE",
        "type": "Receiver Line Card Restored",
        "description": "A line card identified by the passed address is restored",
        "concerns": "Line card number",
    },
    "YF": {
        "event": "YF",
        "type": "Parameter Checksum Fail",
        "description": "System data corrupted",
        "concerns": None,
    },
    "YG": {
        "event": "YG",
        "type": "Parameter Changed",
        "description": "A TRANSMITTER’S parameters have been changed",
        "concerns": None,
    },
    "YH": {
        "event": "YH",
        "type": "Bell Restored",
        "description": "A trouble condition has been restored on a Local Bell, Siren, or Annunciator",
        "concerns": None,
    },
    "YI": {
        "event": "YI",
        "type": "Overcurrent Trouble",
        "description": "An Expansion Device has detected an overcurrent condition",
        "concerns": None,
    },
    "YJ": {
        "event": "YJ",
        "type": "Overcurrent Restore",
        "description": "An Expansion Device has restored from an overcurrent condition",
        "concerns": None,
    },
    "YK": {
        "event": "YK",
        "type": "Communications Restoral",
        "description": "TRANSMITTER has resumed communication with a RECEIVER",
        "concerns": None,
    },
    "YM": {
        "event": "YM",
        "type": "System Battery Missing",
        "description": "TRANSMITTER/RECEIVER battery is missing",
        "concerns": None,
    },
    "YN": {
        "event": "YN",
        "type": "Invalid Report",
        "description": "TRANSMITTER has sent a packet with invalid data",
        "concerns": None,
    },
    "YO": {
        "event": "YO",
        "type": "Unknown Message",
        "description": "An unknown message was received from automation or the printer",
        "concerns": None,
    },
    "YP": {
        "event": "YP",
        "type": "Power Supply Trouble",
        "description": "TRANSMITTER/RECEIVER has a problem with the power supply",
        "concerns": None,
    },
    "YQ": {
        "event": "YQ",
        "type": "Power Supply Restored",
        "description": "TRANSMITTER’S/RECEIVER’S power supply has been restored",
        "concerns": None,
    },
    "YR": {
        "event": "YR",
        "type": "System Battery Restoral",
        "description": "Low battery has been corrected",
        "concerns": None,
    },
    "YS": {
        "event": "YS",
        "type": "Communications Trouble",
        "description": "RECEIVER and TRANSMITTER",
        "concerns": None,
    },
    "YT": {
        "event": "YT",
        "type": "System Battery Trouble",
        "description": "Low battery in control/communicator",
        "concerns": None,
    },
    "YU": {
        "event": "YU",
        "type": "Diagnostic Error",
        "description": "An expansion/peripheral device is reporting a diagnostic error",
        "concerns": "Condition number",
    },
    "YW": {
        "event": "YW",
        "type": "Watchdog Reset",
        "description": "The TRANSMITTER created an internal reset",
        "concerns": None,
    },
    "YX": {
        "event": "YX",
        "type": "Service Required",
        "description": "A TRANSMITTER/RECEIVER needs service",
        "concerns": None,
    },
    "YY": {
        "event": "YY",
        "type": "Status Report",
        "description": "This is a header for an account status report transmission",
        "concerns": None,
    },
    "YZ": {
        "event": "YZ",
        "type": "Service Completed",
        "description": "Required TRANSMITTER / RECEIVER service completed",
        "concerns": "Mfr defined",
    },
    "ZA": {
        "event": "ZA",
        "type": "Freeze Alarm",
        "description": "Low temperature detected at premises",
        "concerns": "Zone or point",
    },
    "ZB": {
        "event": "ZB",
        "type": "Freeze Bypass",
        "description": "Low temperature detection has been bypassed",
        "concerns": "Zone or point",
    },
    "ZH": {
        "event": "ZH",
        "type": "Freeze Alarm Restore",
        "description": "Alarm condition eliminated",
        "concerns": "Zone or point",
    },
    "ZJ": {
        "event": "ZJ",
        "type": "Freeze Trouble Restore",
        "description": "Trouble condition eliminated",
        "concerns": "Zone or point",
    },
    "ZR": {
        "event": "ZR",
        "type": "Freeze Restoral",
        "description": "Alarm/trouble condition has been eliminated",
        "concerns": "Zone or point",
    },
    "ZS": {
        "event": "ZS",
        "type": "Freeze Supervisory",
        "description": "Unsafe freeze detection system condition",
        "concerns": "Zone or point",
    },
    "ZT": {
        "event": "ZT",
        "type": "Freeze Trouble",
        "description": "Zone disabled by fault",
        "concerns": "Zone or point",
    },
    "ZU": {
        "event": "ZU",
        "type": "Freeze Unbypass",
        "description": "Low temperature detection bypass removed",
        "concerns": "Zone or point",
    },
    "ZY": {
        "event": "ZY",
        "type": "Common Event",
        "description": "Device was switched on",
        "concerns": "Hub",
    },
    "ZZ": {
        "event": "ZZ",
        "type": "Common Event",
        "description": "Device was switched off",
        "concerns": "Hub",
    },
}

CID_SIA_MAPPING = {
    "100": {"1": "MA", "3": "MH"},
    "101": {"1": "QA", "3": "QH"},
    "110": {"1": "FA", "3": "FH"},
    "111": {"1": "FA", "3": "FH"},
    "112": {"1": "FA", "3": "FH"},
    "113": {"1": "WA", "3": "WH"},
    "114": {"1": "KA", "3": "KH"},
    "117": {"1": "FA", "3": "FH"},
    "120": {"1": "PA", "3": "PH"},
    "121": {"1": "HA", "3": "HH"},
    "122": {"1": "HA", "3": "HH"},
    "124": {"1": "HA", "3": "HH"},
    "125": {"1": "HA", "3": "HH"},
    "130": {"1": "BA", "3": "BH"},
    "131": {"1": "BA", "3": "BH"},
    "132": {"1": "BA", "3": "BH"},
    "133": {"1": "BA", "3": "BH"},
    "134": {"1": "BA", "3": "BH"},
    "135": {"1": "BA", "3": "BH"},
    "136": {"1": "BA", "3": "BH"},
    "137": {"1": "TA", "3": "TR"},
    "138": {"1": "BA", "3": "BH"},
    "139": {"1": "BA", "3": "BH"},
    "140": {"1": "BA", "3": "BH"},
    "143": {"1": "ET", "3": "ER"},
    "144": {"1": "TA", "3": "TR"},
    "146": {"1": "HA", "3": "HH"},
    "150": {"1": "UA", "3": "UH"},
    "151": {"1": "GA", "3": "GH"},
    "158": {"1": "KA", "3": "KH"},
    "159": {"1": "ZA", "3": "ZH"},
    "162": {"1": "GA", "3": "GH"},
    "300": {"1": "YX", "3": "YZ"},
    "301": {"1": "AT", "3": "AR"},
    "302": {"1": "YT", "3": "YR"},
    "303": {"1": "YX", "3": "YZ"},
    "304": {"1": "YX", "3": "YZ"},
    "305": {"1": "YW", "3": "YZ"},
    "306": {"1": "YX", "3": "YZ"},
    "307": {"1": "YX", "3": "YZ"},
    "308": {"1": "YX", "3": "YZ"},
    "309": {"1": "YT", "3": "YR"},
    "310": {"1": "YX", "3": "YZ"},
    "311": {"1": "YM", "3": "YR"},
    "312": {"1": "YP", "3": "YQ"},
    "320": {"1": "RC", "3": "RO"},
    "321": {"1": "YX", "3": "YZ"},
    "322": {"1": "YX", "3": "YZ"},
    "323": {"1": "RC", "3": "RO"},
    "324": {"1": "RC", "3": "RO"},
    "325": {"1": "RC", "3": "RO"},
    "330": {"1": "YX", "3": "YZ"},
    "331": {"1": "YX", "3": "YZ"},
    "332": {"1": "YX", "3": "YZ"},
    "333": {"1": "ET", "3": "ER"},
    "334": {"1": "YX", "3": "YZ"},
    "335": {"1": "VO", "3": "VI"},
    "336": {"1": "VT", "3": "VR"},
    "337": {"1": "ET", "3": "ER"},
    "338": {"1": "ET", "3": "ER"},
    "339": {"1": "ET", "3": "ER"},
    "341": {"1": "ET", "3": "ER"},
    "342": {"1": "ET", "3": "ER"},
    "343": {"1": "ET", "3": "ER"},
    "344": {"1": "YC", "3": "YK"},
    "350": {"1": "YC", "3": "YK"},
    "351": {"1": "LT", "3": "LR"},
    "352": {"1": "LT", "3": "LR"},
    "353": {"1": "YC", "3": "YK"},
    "354": {"1": "YC", "3": "YK"},
    "355": {"1": "YC", "3": "YK"},
    "356": {"1": "YC", "3": "YK"},
    "357": {"1": "YC", "3": "YK"},
    "358": {"1": "YC", "3": "YK"},
    "359": {"1": "YC", "3": "YK"},
    "360": {"1": "YC", "3": "YK"},
    "373": {"1": "FT", "3": "FJ"},
    "374": {"1": "EA", "3": "BH"},
    "375": {"1": "PT", "3": "PJ"},
    "376": {"1": "HT", "3": "HR"},
    "380": {"1": "YX", "3": "YZ"},
    "381": {"1": "YC", "3": "YK"},
    "382": {"1": "YC", "3": "YK"},
    "393": {"1": "YX", "3": "YZ"},
    "400": {"1": "OP", "3": "CL"},
    "401": {"1": "OP", "3": "CL"},
    "402": {"1": "OB", "3": "CB"},
    "403": {"1": "OA", "3": "CA"},
    "406": {"1": "OC", "3": "OC"},
    "409": {"1": "OS", "3": "CS"},
    "412": {"1": "RB", "3": "RB"},
    "414": {"1": "YT", "3": "YT"},
    "453": {"1": "OI", "3": "OI"},
    "421": {"1": "DD", "3": "DD"},
    "423": {"1": "DF", "3": "DF"},
    "441": {"1": "CG", "3": "CG"},
    "454": {"1": "CI", "3": "CI"},
    "456": {"1": "CG", "3": "OG"},
    "457": {"1": "EE", "3": "EE"},
    "461": {"1": "DD", "3": "DD"},
    "462": {"1": "DO", "3": "DO"},
    "463": {"1": "YY", "3": "YY"},
    "470": {"1": "BB", "3": "BB"},
    "471": {"1": "FB", "3": "FB"},
    "473": {"1": "BB", "3": "BB"},
    "570": {"1": "BB", "3": "BU"},
    "601": {"1": "RX", "3": "RX"},
    "602": {"1": "RP", "3": "RP"},
    "604": {"1": "FX", "3": "FK"},
    "608": {"1": "TX", "3": "TX"},
    "622": {"1": "JL", "3": "JL"},
    "623": {"1": "JL", "3": "JL"},
    "624": {"1": "JO", "3": "JO"},
    "625": {"1": "JT", "3": "JT"},
    "626": {"1": "JD", "3": "JD"},
    "627": {"1": "LB", "3": "LB"},
    "628": {"1": "LX", "3": "LX"},
    "632": {"1": "JS", "3": "JS"},
    "654": {"1": "NA", "3": "NA"},
    "900": {"1": "RR", "3": "RR"},
}
